EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Applications_SetDeployableDependencies',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Sets the dependency relationships between the specified deployable and its dependents'
GO

IF OBJECT_ID('[Applications_SetDeployableDependencies]') IS NOT NULL DROP PROCEDURE [Applications_SetDeployableDependencies]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Applications_SetDeployableDependencies]
(
	@Deployable_Id INT,
	@DependsOn_Deployables_Csv VARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

		DELETE [DeployableDependencies]
		 WHERE [Deployable_Id] = @Deployable_Id

		INSERT INTO [DeployableDependencies]
			(
				[Deployable_Id],
				[DependsOn_Deployable_Id]
			)
		SELECT
				@Deployable_Id,
				CAST(CSV.[Value_Text] AS INT)
		  FROM [dbo].[CsvToTable](@DependsOn_Deployables_Csv, ',') CSV

		DECLARE @Application_Id INT 
		    SET @Application_Id = (SELECT [Application_Id] 
			                         FROM [Deployables]
			                        WHERE [Deployable_Id] = @Deployable_Id)

		/* Raise Event */
		EXEC [Events_RaiseEvent] 'APPMDD',@Application_Id,@Deployable_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Applications_SetDeployableDependencies] TO [BuildMasterUser_Role]