EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_CreateBuild',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Build_Id',
    /* Description_Text        */ 'Creates a new build of an application.'
GO

IF OBJECT_ID('[Builds_CreateBuild]') IS NOT NULL DROP PROCEDURE [Builds_CreateBuild]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_CreateBuild]
(
	@Application_Id INT,
	@Release_Id INT,
	@Build_Number BUILDNUMBER,
	@Variables_Table dbo.DeploymentVariableEntry READONLY,
	@Pipeline_Name VARCHAR(100),
	@Build_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Build_Sequence INT

	IF @Application_Id IS NULL
		SET @Build_Sequence = COALESCE((SELECT MAX([Build_Sequence])
		                                  FROM [Builds]
										 WHERE [Application_Id] IS NULL), 0) + 1
	ELSE IF @Release_Id IS NULL
		SET @Build_Sequence = COALESCE((SELECT MAX([Build_Sequence])
		                                  FROM [Builds]
										 WHERE [Application_Id] = @Application_Id
										   AND [Release_Id] IS NULL), 0) + 1
	ELSE
		SET @Build_Sequence = COALESCE((SELECT MAX([Build_Sequence])
		                                  FROM [Builds]
										 WHERE [Application_Id] = @Application_Id
										   AND [Release_Id] = @Release_Id), 0) + 1

	INSERT INTO [Builds]
	(
		[Release_Id],
		[Build_Number],
		[BuildStatus_Name],
		[CreatedBy_User_Name],
		[CreatedOn_Date],
		[ModifiedBy_User_Name],
		[ModifiedOn_Date],
		[Build_Sequence],
		[Application_Id],
		[Pipeline_Name]
	)
	VALUES
	(
		@Release_Id,
		@Build_Number,
		'Active',
		dbo.Session_GetUserName(),
		GETUTCDATE(),
		dbo.Session_GetUserName(),
		GETUTCDATE(),
		@Build_Sequence,
		@Application_Id,
		@Pipeline_Name
	)

	SET @Build_Id = SCOPE_IDENTITY()

	INSERT INTO [BuildVariables]
	SELECT [Build_Id] = @Build_Id,
		   [Variable_Name],
		   [ValueType_Code],
		   [Variable_Value],
		   [Sensitive_Indicator],
		   [EvaluateVariables_Indicator]
	  FROM @Variables_Table


	DECLARE @Release_Number RELEASENUMBER
	SET @Release_Number = (SELECT [Release_Number]
	                         FROM [Releases]
							WHERE [Release_Id] = @Release_Id)

	IF @Release_Number IS NOT NULL
		EXEC [Events_RaiseEvent] 'BLDNEW', @Application_Id, @Release_Number, @Build_Number
	ELSE
		EXEC [Events_RaiseEvent] 'BLDNEW', @Application_Id, '', @Build_Number

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Builds_CreateBuild] TO [BuildMasterUser_Role]
