EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ConfigurationFiles_UpdateConfigurationFile',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates metadata for an existing configuration file.'
GO

IF OBJECT_ID('[ConfigurationFiles_UpdateConfigurationFile]') IS NOT NULL DROP PROCEDURE [ConfigurationFiles_UpdateConfigurationFile]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ConfigurationFiles_UpdateConfigurationFile]
(
	@ConfigurationFile_Id INT,
	@Active_Indicator YNINDICATOR,
	@ConfigurationFile_Name NVARCHAR(100),
	@FilePath_Text VARCHAR(500),
	@Description_Text NVARCHAR(MAX),
	@Deployable_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Application_Id INT
	    SET @Application_Id = (SELECT [Application_Id] 
	                             FROM [ConfigurationFiles]
 	                            WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id)

	DECLARE @Other_Application_Id INT
	SET @Other_Application_Id = (SELECT [Application_Id] 
	                               FROM [Deployables]
 	                              WHERE [Deployable_Id] = @Deployable_Id)

	IF @Other_Application_Id IS NOT NULL AND @Other_Application_Id <> @Application_Id
		RAISERROR('Cannot change configuration file deployable to a deployable of a different application.', 16, 1)

	UPDATE [ConfigurationFiles]
	   SET [Active_Indicator] = @Active_Indicator,
	       [ConfigurationFile_Name] = NULLIF(@ConfigurationFile_Name, ''),
		   [FilePath_Text] = @FilePath_Text,
		   [Description_Text] = NULLIF(@Description_Text, ''),
		   [Deployable_Id] = @Deployable_Id
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id

	EXEC [Events_RaiseEvent] 'CFGMOD', @Application_Id, @ConfigurationFile_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ConfigurationFiles_UpdateConfigurationFile] TO [BuildMasterUser_Role]
