EXEC [__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Issues_CreateIssue',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Issue_Id',
    /* Description_Text        */ 'Creates an issue for a release of an application.'
GO

IF OBJECT_ID('[Issues_CreateIssue]') IS NOT NULL DROP PROCEDURE [Issues_CreateIssue]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Issues_CreateIssue]
(
    @Application_Id INT,
    @Release_Number RELEASENUMBER,
    @Type_Text NVARCHAR(50),
    @Title_Text NVARCHAR(200),
    @Description_Text NVARCHAR(MAX),
    @Closed_Indicator YNINDICATOR, 
    @Build_Number BUILDNUMBER = NULL,
    @CreatedBy_User_Name USERNAME = NULL,
    @CreatedOn_Date DATETIME = NULL,
    @IssueTracker_IssueId_Text NVARCHAR(100) = NULL,
    @IssueTracker_IssueStatus_Text NVARCHAR(100) = NULL,
    @IssueTracker_LastSync_Date DATETIME = NULL,
    @IssueTracker_IssueUrl_Text NVARCHAR(255) = NULL,
    @Issue_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
    BEGIN TRANSACTION

    SET @Issue_Id = COALESCE((SELECT MAX([Issue_Id])
                                FROM [Issues]
                               WHERE [Application_Id] = @Application_Id), 0) + 1

    DECLARE @Release_Id INT
    SELECT @Release_Id = [Release_Id]
      FROM [Releases]
     WHERE [Application_Id] = @Application_Id
       AND [Release_Number] = @Release_Number

    INSERT INTO [Issues]
    (
        [Issue_Id],
        [Application_Id],
        [Release_Id],
        [IssueTracker_IssueId_Text],
        [IssueTracker_IssueStatus_Text],
        [IssueTracker_IssueUrl_Text],
        [IssueTracker_LastSync_Date],
        [Type_Text],
        [Title_Text],
        [Description_Text],
        [Closed_Indicator],
        [ClosedOn_Date],
        [CreatedBy_User_Name],
        [CreatedOn_Date]
    )
    VALUES
    (
        @Issue_Id,
        @Application_Id,
        @Release_Id,
        @IssueTracker_IssueId_Text,
        @IssueTracker_IssueStatus_Text,
        @IssueTracker_IssueUrl_Text,
        @IssueTracker_LastSync_Date,
        @Type_Text,
        @Title_Text,
        NULLIF(@Description_Text, ''),
        @Closed_Indicator,
        CASE WHEN @Closed_Indicator = 'Y' THEN GETUTCDATE() ELSE NULL END,
        COALESCE(@CreatedBy_User_Name, dbo.Session_GetUserName()),
        COALESCE(@CreatedOn_Date, GETUTCDATE())
    )

    COMMIT
END TRY BEGIN CATCH
    IF XACT_STATE()<>0 ROLLBACK
    EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Issues_CreateIssue] TO [BuildMasterUser_Role]
